@@ -1,8 +1,8 @@
 # encoding: utf-8
 
-require 'hocon'
-require 'hocon/config_mergeable'
-require 'hocon/config_error'
+require_relative '../hocon'
+require_relative '../hocon/config_mergeable'
+require_relative '../hocon/config_error'
 
 #
 # An immutable map from config paths to config values. Paths are dot-separated
